@@ -15,11 +15,15 @@
 #' Note that if using the rvn_rvh_overwrite function and the filename and basefile arguments are the same, the
 #' original file will be overwritten while preserving lines outside of the subbasin and HRU blocks.
 #'
+#' If using \code{rvn_rvh_write}, the SBtable or HRUtable parameters may be omitted and provided as \code{NULL}.
+#' In these cases, those sections will not be written in the rvh file. This may be useful in cases where one wishes to
+#' separate the SubBasins and HRUs in different files.
+#'
 #' @param filename filepath of rvh file to write to (with .rvh extension)
 #' @param SBtable Valid subbasin dataframe with required columns "SBID", "Name", "Downstream_ID", "Profile",
 #'   "ReachLength", and "Gauged". Can have additional columns.
 #' @param HRUtable Valid HRU dataframe with required columns 'ID', 'Area', 'Elevation', 'Latitude', 'Longitude',
-#'    'SBID', 'LandUse', 'Vegetation', 'SoilProfile', 'Terrain', 'Aquifer', 'Slope', and 'Aspect'. Can have additional columns.
+#'    'SBID', 'LandUse', 'Vegetation', 'SoilProfile', 'Aquifer', 'Terrain', 'Slope', and 'Aspect'. Can have additional columns.
 #' @param description (optional) Description added after file header
 #' @param author (optional) Name of author, to be printed in file header.
 #' @param basefile original rvh file to overwrite (only used with rvn_rvh_overwrite)
@@ -66,31 +70,43 @@
 #'                   HRUtable = rvh$HRUtable)
 #'
 #' @export rvn_rvh_write
-rvn_rvh_write <- function(filename, SBtable, HRUtable,
+rvn_rvh_write <- function(filename, SBtable=NULL, HRUtable=NULL,
                           description="Generated by RavenR rvn_rvh_write",
                           author=NULL) {
 
+  if(missing(filename)) {
+    stop("No filename provided!")
+  }
+
   rvn_write_Raven_newfile(filename = filename,
               description,
-              filetype='.rvh',
+              filetype = '.rvh',
               author = author)
   #-- SubBasins
-  rvn_write_Raven_label('SubBasins',filename)
-  rvn_write_Raven_table(attributes = c('Attributes','NAME','DOWNSTREAM_ID','PROFILE','REACH_LENGTH','GAUGED'),
-                   units = c('Units','none','none','none','km','none'),
-                   df = SBtable[c('SBID','Name','Downstream_ID','Profile','ReachLength','Gauged')],
-                   filename = filename)
-  rvn_write_Raven_label('EndSubBasins\n',filename)
+  if (!is.null(SBtable)) {
+    rvn_write_Raven_label('SubBasins',filename)
+    rvn_write_Raven_table(attributes = c('Attributes','NAME','DOWNSTREAM_ID','PROFILE','REACH_LENGTH','GAUGED'),
+                          units = c('Units','none','none','none','km','none'),
+                          df = SBtable[c('SBID','Name','Downstream_ID','Profile','ReachLength','Gauged')],
+                          filename = filename)
+    rvn_write_Raven_label('EndSubBasins\n',filename)
+  } else {
+    warning(sprintf("No SBtable provided, SubBasins block not written to file %s",filename))
+  }
 
   #-- HRUs
-  rvn_write_Raven_label("HRUs",filename)
-  rvn_write_Raven_table(attributes = c('Attributes','AREA', 'ELEVATION','LATITUDE','LONGITUDE','BASIN_ID','LAND_USE_CLASS',
-                                  'VEG_CLASS','SOIL_PROFILE','AQUIFER_PROFILE','TERRAIN_CLASS','SLOPE','ASPECT'),
-                   units = c('Units','km2','masl','deg','deg','none','none','none','none','none','none','deg','degN'),
-                   df = HRUtable[c('ID','Area','Elevation','Latitude','Longitude','SBID','LandUse',
-                                   'Vegetation','SoilProfile','Aquifer','Terrain','Slope','Aspect')],
-                   filename = filename)
-  rvn_write_Raven_label("EndHRUs\n", filename)
+  if (!is.null(HRUtable)) {
+    rvn_write_Raven_label("HRUs",filename)
+    rvn_write_Raven_table(attributes = c('Attributes','AREA', 'ELEVATION','LATITUDE','LONGITUDE','BASIN_ID','LAND_USE_CLASS',
+                                         'VEG_CLASS','SOIL_PROFILE','AQUIFER_PROFILE','TERRAIN_CLASS','SLOPE','ASPECT'),
+                          units = c('Units','km2','masl','deg','deg','none','none','none','none','none','none','deg','degN'),
+                          df = HRUtable[c('ID','Area','Elevation','Latitude','Longitude','SBID','LandUse',
+                                          'Vegetation','SoilProfile','Aquifer','Terrain','Slope','Aspect')],
+                          filename = filename)
+    rvn_write_Raven_label("EndHRUs\n", filename)
+  } else {
+    warning(sprintf("No HRUtable provided, HRUs block not written to file %s",filename))
+  }
 
   return(TRUE)
 }
